@@ -1,8 +1,8 @@
 $( document ).ready(function() {
     $('[data-toggle="tooltip"]').tooltip();
     window.nautilus = new Nautilus({
-        title: "{{ title }}",
-        description: "{{ description }}",
+        title: "{{ title|safe }}",
+        description: "{{ description|safe }}",
         database_name: "{{ db_name }}.{{ db_version }}",
         database_version: "{{ db_version }}",
         nb_items_per_page: {{ nb_items_per_page }},
@@ -10,7 +10,7 @@ $( document ).ready(function() {
         show_description: {{ show_description|lower }},
         randomize: {{ randomize|lower }},
         debug: {{ debug }},
-        i18n: {loading: "{{ loading_label}}",},
+        i18n: {loading: "{{ loading_label | safe}}",},
     });
     window.nautilus.start();
 });
