@@ -9,7 +9,6 @@
   - handles infinite scroll for search and home (random)
 
   Dependencies:
-    - imported zimwriterfs.js script
     - PouchDB, jQuery, ScrollMagic, videojs, ogvjs, videojs-ogvjs, SugarJS
     - database.js file containing a DATABASE Array of documents.
 
@@ -28,7 +27,6 @@ var Nautilus = (function() {
     nb_items_per_page: 10,
     index_database: false,
     index_database_fields: ["ti", "aut"],
-    in_zim: IS_IN_ZIM,
     files_prefix: 'files/',
     show_description: true,
     randomize: true,
@@ -75,16 +73,10 @@ var Nautilus = (function() {
 
   /*** ZIM-RELATED ***/
   Nautilus.prototype.get_image_path = function (filepath) {
-    if (this.options.in_zim) {
-      return ZIM_IMG_NS + filepath;
-    }
     return filepath;
   }
 
   Nautilus.prototype.get_meta_path = function (filepath) {
-    if (this.options.in_zim) {
-      return ZIM_META_NS + filepath;
-    }
     return filepath;
   }
 
@@ -228,6 +220,7 @@ var Nautilus = (function() {
       let body_tmpl = Handlebars.templates.media_player;
       $('#modal .modal-title').html(title_tmpl({title: doc.title}));
       $('#modal .modal-body').html(body_tmpl({doc: doc, i18n: _this.options.i18n}));
+      $('.video-js').each(function(){ videojs($(this)[0], videojs_options)});
     });
   }
 
@@ -335,13 +328,14 @@ var Nautilus = (function() {
     }
 
     let details = this.getDetailsFor(fp);
-    if (details.is_audio || details.is_video || multiple)
-      target = "javascript:nautilus.openMediaPlayer('" + db_doc._id + "');";
+    let popup = (details.is_audio || details.is_video || multiple) ? 1 : 0;
 
     let row = {
+      docid: db_doc._id,
       title: db_doc.ti,
       author: this.options.show_author ? db_doc.aut : null,
       description: this.options.show_description ? db_doc.dsc : null,
+      popup: popup,
       target: target,
       multiple: multiple,
     };
@@ -356,7 +350,7 @@ var Nautilus = (function() {
     _this.on_rows_updated();
   };
 
-  Nautilus.prototype.update_sroll_scene = function () {
+  Nautilus.prototype.update_scroll_scene = function () {
     if (this.scroll_scene == null)
       this.init_scroll();
     else
@@ -394,9 +388,16 @@ var Nautilus = (function() {
   };
 
   Nautilus.prototype.on_rows_updated = function () {
+    // register popup links
+    var _this = this;
+    $("a[data-popup=1]").on("click", function (e) {
+      e.preventDefault();
+      let doc_id = $(e.currentTarget).data("doc-id");
+      _this.openMediaPlayer(doc_id);
+    });
     if (!this.should_scroll)
       return;
-    this.update_sroll_scene(); // make sure the scene gets the new start position
+    this.update_scroll_scene(); // make sure the scene gets the new start position
     this.disableInfiniteScroll();
   };
 
